@@ -123,3 +123,15 @@ def test_use_custom_handler(ext_markdown):
     """Assert that we use the custom handler declared in an individual autodoc instruction."""
     with pytest.raises(ModuleNotFoundError):
         ext_markdown.convert("::: tests.fixtures.headings\n    handler: not_here")
+
+
+def test_dont_register_every_identifier_as_anchor(plugin):
+    """Assert that we don't preemptively register all identifiers of a rendered object."""
+    renderer = plugin._handlers.get_handler("python").renderer  # noqa: WPS437
+    ids = {"id1", "id2", "id3"}
+    renderer.get_anchors = lambda _: ids
+    plugin.md.convert("::: tests.fixtures.headings")
+    autorefs = plugin.md.parser.blockprocessors["mkdocstrings"]._autorefs  # noqa: WPS219,WPS437
+    for identifier in ids:
+        assert identifier not in autorefs._url_map  # noqa: WPS437
+        assert identifier not in autorefs._abs_url_map  # noqa: WPS437
